@@ -88,11 +88,13 @@ def send_sms():
     telma = (msisdn[-9:]).startswith("34")
 
     smpp = json_doc.get('sender_id')
-    if smpp == "mfs":
-        sender_id = "mfs"
-    elif telma:
+    # if smpp == "mfs":
+    #     sender_id = "mfs"
+    if telma:
         LOGS.logger.info("MSISDN Telma redirected to Orange SMPP.")
         sender_id = "orange"
+    elif smpp == "mfs":
+        sender_id = "mfs"
     elif not telma and smpp == 'orange':
         LOGS.logger.warning(
             "MSISDN '{}' is not Telma but targeting Orange SMPP. "
